@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import sys
 
 
@@ -5,10 +7,10 @@ if __name__ == "__main__":
     import cProfile
     import pstats
 
-    import pytest  # NOQA
+    import pytest  # noqa: F401
 
     script = sys.argv[1:] if len(sys.argv) > 1 else ["empty.py"]
-    cProfile.run("pytest.cmdline.main(%r)" % script, "prof")
+    cProfile.run(f"pytest.cmdline.main({script!r})", "prof")
     p = pstats.Stats("prof")
     p.strip_dirs()
     p.sort_stats("cumulative")
