@@ -1,8 +1,8 @@
-# -*- coding: utf-8 -*-
-from six.moves import range
+from __future__ import annotations
 
 import pytest
 
+
 SKIP = True
 
 
