@@ -1,5 +1,8 @@
 """Module containing a parametrized tests testing cross-python serialization
 via the pickle module."""
+
+from __future__ import annotations
+
 import shutil
 import subprocess
 import textwrap
@@ -32,14 +35,12 @@ class Python:
         dumpfile = self.picklefile.with_name("dump.py")
         dumpfile.write_text(
             textwrap.dedent(
-                r"""
+                rf"""
                 import pickle
-                f = open({!r}, 'wb')
-                s = pickle.dump({!r}, f, protocol=2)
+                f = open({str(self.picklefile)!r}, 'wb')
+                s = pickle.dump({obj!r}, f, protocol=2)
                 f.close()
-                """.format(
-                    str(self.picklefile), obj
-                )
+                """
             )
         )
         subprocess.run((self.pythonpath, str(dumpfile)), check=True)
@@ -48,17 +49,15 @@ class Python:
         loadfile = self.picklefile.with_name("load.py")
         loadfile.write_text(
             textwrap.dedent(
-                r"""
+                rf"""
                 import pickle
-                f = open({!r}, 'rb')
+                f = open({str(self.picklefile)!r}, 'rb')
                 obj = pickle.load(f)
                 f.close()
-                res = eval({!r})
+                res = eval({expression!r})
                 if not res:
                     raise SystemExit(1)
-                """.format(
-                    str(self.picklefile), expression
-                )
+                """
             )
         )
         print(loadfile)
