@@ -1,6 +1,10 @@
+# mypy: allow-untyped-defs
+from __future__ import annotations
+
 import argparse
 import pathlib
 
+
 HERE = pathlib.Path(__file__).parent
 TEST_CONTENT = (HERE / "template_test.py").read_bytes()
 
