@@ -1,8 +1,10 @@
-from typing import List
-from unittest import IsolatedAsyncioTestCase  # type: ignore
+# mypy: allow-untyped-defs
+from __future__ import annotations
+
+from unittest import IsolatedAsyncioTestCase
 
 
-teardowns = []  # type: List[None]
+teardowns: list[None] = []
 
 
 class AsyncArguments(IsolatedAsyncioTestCase):
