@@ -1,11 +1,14 @@
-# -*- coding: utf-8 -*-
 """
 This is the script that is actually frozen into an executable: simply executes
-py.test main().
+pytest main().
 """
 
+from __future__ import annotations
+
+
 if __name__ == "__main__":
     import sys
+
     import pytest
 
     sys.exit(pytest.main())
