@@ -1,4 +1,7 @@
-# -*- coding: utf-8 -*-
+# mypy: allow-untyped-defs
+from __future__ import annotations
+
+
 def test_upper():
     assert "foo".upper() == "FOO"
 
