@@ -1,13 +1,14 @@
 # mypy: allow-untyped-defs
 from __future__ import annotations
 
+from collections.abc import Generator
 import io
+from io import StringIO
 import os
 from pathlib import Path
 import re
 import shutil
 import sys
-from typing import Generator
 from unittest import mock
 
 from _pytest._io import terminalwriter
@@ -68,6 +69,7 @@ win32 = int(sys.platform == "win32")
 class TestTerminalWriter:
     @pytest.fixture(params=["path", "stringio"])
     def tw(self, request, tmp_path: Path) -> Generator[terminalwriter.TerminalWriter]:
+        f: io.TextIOWrapper | StringIO
         if request.param == "path":
             p = tmp_path.joinpath("tmpfile")
             f = open(str(p), "w+", encoding="utf8")
