@@ -1,3 +1,6 @@
+# mypy: allow-untyped-defs
+from __future__ import annotations
+
 from pytest_bdd import given
 from pytest_bdd import scenario
 from pytest_bdd import then
