@@ -1,8 +1,10 @@
+# mypy: allow-untyped-defs
+from __future__ import annotations
+
 import os
 import sys
 import textwrap
 from typing import Any
-from typing import Dict
 
 import _pytest._code
 from _pytest.config import ExitCode
@@ -35,9 +37,9 @@ class TestModule:
             [
                 "*import*mismatch*",
                 "*imported*test_whatever*",
-                "*%s*" % p1,
+                f"*{p1}*",
                 "*not the same*",
-                "*%s*" % p2,
+                f"*{p2}*",
                 "*HINT*",
             ]
         )
@@ -261,6 +263,69 @@ class TestClass:
         result = pytester.runpytest()
         assert result.ret == ExitCode.NO_TESTS_COLLECTED
 
+    def test_does_not_discover_properties(self, pytester: Pytester) -> None:
+        """Regression test for #12446."""
+        pytester.makepyfile(
+            """\
+            class TestCase:
+                @property
+                def oops(self):
+                    raise SystemExit('do not call me!')
+            """
+        )
+        result = pytester.runpytest()
+        assert result.ret == ExitCode.NO_TESTS_COLLECTED
+
+    def test_does_not_discover_instance_descriptors(self, pytester: Pytester) -> None:
+        """Regression test for #12446."""
+        pytester.makepyfile(
+            """\
+            # not `@property`, but it acts like one
+            # this should cover the case of things like `@cached_property` / etc.
+            class MyProperty:
+                def __init__(self, func):
+                    self._func = func
+                def __get__(self, inst, owner):
+                    if inst is None:
+                        return self
+                    else:
+                        return self._func.__get__(inst, owner)()
+
+            class TestCase:
+                @MyProperty
+                def oops(self):
+                    raise SystemExit('do not call me!')
+            """
+        )
+        result = pytester.runpytest()
+        assert result.ret == ExitCode.NO_TESTS_COLLECTED
+
+    def test_abstract_class_is_not_collected(self, pytester: Pytester) -> None:
+        """Regression test for #12275 (non-unittest version)."""
+        pytester.makepyfile(
+            """
+            import abc
+
+            class TestBase(abc.ABC):
+                @abc.abstractmethod
+                def abstract1(self): pass
+
+                @abc.abstractmethod
+                def abstract2(self): pass
+
+                def test_it(self): pass
+
+            class TestPartial(TestBase):
+                def abstract1(self): pass
+
+            class TestConcrete(TestPartial):
+                def abstract2(self): pass
+            """
+        )
+        result = pytester.runpytest()
+        assert result.ret == ExitCode.OK
+        result.assert_outcomes(passed=1)
+
 
 class TestFunction:
     def test_getmodulecollector(self, pytester: Pytester) -> None:
@@ -1102,7 +1167,7 @@ class TestTracebackCutting:
 
         tb = None
         try:
-            ns: Dict[str, Any] = {}
+            ns: dict[str, Any] = {}
             exec("def foo(): raise ValueError", ns)
             ns["foo"]()
         except ValueError:
@@ -1208,7 +1273,7 @@ class TestReportInfo:
         classcol = pytester.collect_by_name(modcol, "TestClass")
         assert isinstance(classcol, Class)
         path, lineno, msg = classcol.reportinfo()
-        func = list(classcol.collect())[0]
+        func = next(iter(classcol.collect()))
         assert isinstance(func, Function)
         path, lineno, msg = func.reportinfo()
 
