@@ -1,13 +1,13 @@
 from __future__ import annotations
 
+from collections.abc import Generator
+from collections.abc import Sequence
 from enum import auto
 from enum import Enum
 import os
 from pathlib import Path
 import shutil
 from typing import Any
-from typing import Generator
-from typing import Sequence
 
 from _pytest.compat import assert_never
 from _pytest.config import ExitCode
@@ -69,7 +69,7 @@ class TestNewAPI:
         cache.set("test/broken", [])
 
     @pytest.fixture
-    def unwritable_cache_dir(self, pytester: Pytester) -> Generator[Path, None, None]:
+    def unwritable_cache_dir(self, pytester: Pytester) -> Generator[Path]:
         cache_dir = pytester.path.joinpath(".pytest_cache")
         cache_dir.mkdir()
         mode = cache_dir.stat().st_mode
@@ -104,7 +104,7 @@ class TestNewAPI:
         pytester.makepyfile("def test_error(): raise Exception")
         result = pytester.runpytest()
         assert result.ret == 1
-        # warnings from nodeids, lastfailed, and stepwise
+        # warnings from nodeids and lastfailed
         result.stdout.fnmatch_lines(
             [
                 # Validate location/stacklevel of warning from cacheprovider.
@@ -113,7 +113,7 @@ class TestNewAPI:
                 "  */cacheprovider.py:*: PytestCacheWarning: could not create cache path "
                 f"{unwritable_cache_dir}/v/cache/nodeids: *",
                 '    config.cache.set("cache/nodeids", sorted(self.cached_nodeids))',
-                "*1 failed, 3 warnings in*",
+                "*1 failed, 2 warnings in*",
             ]
         )
 
